home | help
RXVT(1) 			     X Tools				 RXVT(1)

NAME
     rxvt (ouR XVT) - a VT102 emulator for the X window system

SYNOPSIS
     rxvt [options] [-e command [ args ]]

DESCRIPTION
     rxvt,  version  2.7.10,  is a colour vt102 terminal emulator intended as an
     xterm(1) replacement for users who do not require	features  such	as  Tek-
     tronix 4014 emulation and toolkit-style configurability.  As a result, rxvt
     uses  much  less swap space -- a significant advantage on a machine serving
     many X sessions.

OPTIONS
     The rxvt options (mostly a subset of xterm's) are listed below.  In keeping
     with the smaller-is-better philosophy, options may be eliminated or default
     values chosen at compile-time, so options and defaults listed may not accu-
     rately reflect the version installed on your system.   `rxvt  -h'	gives  a
     list  of  major  compile-time options on the Options line.  Option descrip-
     tions may be prefixed with which compile option  each  is	dependent  upon.
     e.g.  `Compile  XIM:' requires XIM on the Options line.  Note: `rxvt -help'
     gives a list of all command-line options compiled into your version.

     Note that rxvt permits the resource name to be used as a long-option (--/++
     option) so the potential command-line options are far  greater  than  those
     listed.  For example: `rxvt --loginShell --color1 Orange'.

     Also  note  that  if you do not explictly specify a font (-fn and -fm) or a
     multichar encoding method (-km), rxvt will select a font for the preferable
     encoding according to your locale.   Supported  encodings	are:  ISO-8859-n
     (n=1...15), KOI8-R, KOI8-U, EUC-JP, Shift_JIS, EUC-KR, EUC-CN (aka GB), and
     Big5.

     The following options are available:

     -help, --help
	    Print out a message describing available options.

     -display displayname
	    Attempt  to  open  a  window  on  the  named X display (-d still re-
	    spected).  In the absence of this option, the display  specified  by
	    the DISPLAY environment variable is used.

     -geometry geom
	    Window geometry (-g still respected); resource geometry.

     -rv|+rvTurn on/off simulated reverse video; resource reverseVideo.

     -j|+j  Turn on/off jump scrolling; resource jumpScroll.

     -ip|+ipTurn  on/off inheriting parent window's pixmap.  Alternative form is
	    -tr; resource inheritPixmap.

     -bg colour
	    Window background colour; resource background.

     -fg colour
	    Window foreground colour; resource foreground.

     -pixmap: file[;geom]
	    Compile XPM: Specify XPM file for the background and also optionally
	    specify its scaling with a geometry string.  Note you  may	need  to
	    add  quotes  to avoid special shell interpretation of the `;' in the
	    command-line; resource backgroundPixmap.

     -cr colour
	    The cursor colour; resource cursorColor.

     -pr colour
	    The mouse pointer colour; resource pointerColor.

     -bd colour
	    The colour of the border between the xterm scrollbar and  the  text;
	    resource borderColor.

     -fn fontname
	    Main normal text font; resource font.

     -fb fontname
	    Main bold text font; resource boldFont.

     -fm fontname
	    Main multicharacter font; resource mfont.

     -km mode
	    Compile  multichar_languages:  Multiple-character  font-set encoding
	    mode; eucj: EUC Japanese encoding.	sjis: Shift JIS encoding.  big5:
	    BIG5 encoding.  gb: GB encoding.  kr: EUC Korean  encoding.   noenc:
	    no encoding; resource multichar_encoding.

     -grk mode
	    Compile  Greek:  Greek  keyboard translation; iso: ISO-8859 mapping.
	    ibm: IBM-437 mapping; resource greek_keyboard.

     -name name
	    Specify the application name under which resources	are  to  be  ob-
	    tained,  rather  than the default executable file name.  Name should
	    not contain `.' or `*' characters.	Also sets  the	icon  and  title
	    name.

     -ls|+lsStart as a login-shell/sub-shell; resource loginShell.

     -ut|+utCompile  utmp: Inhibit/enable writing a utmp entry; resource utmpIn-
	    hibit.

     -vb|+vbTurn on/off visual bell on receipt of a bell character; resource vi-
	    sualBell.

     -sb|+sbTurn on/off scrollbar; resource scrollBar.

     -si|+siTurn  on/off  scroll-to-bottom  on	TTY  output  inhibit;	resource
	    scrollTtyOutput has opposite effect.

     -sk|+skTurn  on/off  scroll-to-bottom  on	keypress; resource scrollTtyKey-
	    press.

     -sw|+swTurn on/off scrolling with the scrollback buffer as  new  lines  ap-
	    pear.  This only takes effect if -si is also given; resource scroll-
	    WithBuffer.

     -sr|+srPut scrollbar on right/left; resource scrollBar_right.

     -st|+stDisplay normal (non XTerm/NeXT) scrollbar without/with a trough; re-
	    source scrollBar_floating.

     -mcc|+mcc
	    Compile  multichar_languages: treat multibyte glyphs as single char-
	    acter for backspace,  delete  and  cursor  movement  keys;	resource
	    multibyte_cursor.

     -iconicStart iconified, if the window manager supports that option.  Alter-
	    native form is -ic.

     -sl number
	    Save  number lines in the scrollback buffer.  See resource entry for
	    limits; resource saveLines.

     -b number
	    Compile frills: Internal border of number pixels.  See resource  en-
	    try for limits; resource internalBorder.

     -w number
	    Compile  frills:  External	border	of number pixels.  Also, -bw and
	    -borderwidth.  See resource entry for limits; resource  externalBor-
	    der.

     -lsp number
	    Compile  linespace:  Lines (pixel height) to insert between each row
	    of the display; resource linespace.

     -tn termname
	    This option specifies the name of the terminal type to be set in the
	    TERM environment variable. This terminal  type  must  exist  in  the
	    termcap(5)	database  and  should have li# and co# entries; resource
	    termName.

     -e command [arguments]
	    Run the command with its command-line arguments in the rxvt  window;
	    also  sets	the window title and icon name to be the basename of the
	    program being executed if neither -title (-T) nor -n  are  given  on
	    the  command  line.   If this option is used, it must be the last on
	    the command-line.  If there is no -e option then the default  is  to
	    run  the  program  specified  by  the SHELL environment variable or,
	    failing that, sh(1).

     -title text
	    Window title (-T still respected); the default title is the basename
	    of the program specified after the -e option, if any, otherwise  the
	    application name; resource title.

     -n textIcon name; the default name is the basename of the program specified
	    after  the	-e  option,  if any, otherwise the application name; re-
	    source iconName.

     -C     Capture system console messages.

     -pt style
	    Compile XIM: input style for input method; OverTheSpot,  OffTheSpot,
	    Root; resource preeditType.

     -im text
	    Compile XIM: input method name.  resource inputMethod.

     -mod modifier
	    Override  detection  of Meta modifier with specified key: alt, meta,
	    hyper, super, mod1, mod2, mod3, mod4, mod5; resource modifier.

     -xrm resourcestring
	    No effect on rxvt.	Simply passes through an  argument  to	be  made
	    available in the instance's argument list.	Appears in WM_COMMAND in
	    some window managers.

RESOURCES (available also as long-options)
     Note:  `rxvt  --help' gives a list of all resources (long options) compiled
     into your version.  If compiled with internal Xresources support (i.e. rxvt
     -h lists .Xdefaults) then rxvt accepts application  defaults  set	in  XAP-
     PLOADDIR/Rxvt    (compile-time    defined:   usually   /usr/lib/X11/app-de-
     faults/Rxvt) and resources set in ~/.Xdefaults, or ~/.Xresources if ~/.Xde-
     faults does not exist.  Note that when reading X resources, rxvt recognizes
     two class names: XTerm and Rxvt.  The class  name	XTerm  allows  resources
     common to both rxvt and xterm to be easily configured, while the class name
     Rxvt  allows resources unique to rxvt, notably colours and key-handling, to
     be shared between different rxvt configurations.  If no resources are spec-
     ified, suitable defaults will be used.  Command-line arguments can be  used
     to override resource settings.  The following resources are allowed:

     geometry: geom
	    Create  the  window  with  the  specified X window geometry [default
	    80x24]; option -geometry.

     background: colour
	    Use the specified colour as the window's background colour	[default
	    White]; option -bg.

     foreground: colour
	    Use  the specified colour as the window's foreground colour [default
	    Black]; option -fg.

     colorn: colour
	    Use the specified colour for the colour value n,  where  0-7  corre-
	    sponds  to	low-intensity  (normal)  colours and 8-15 corresponds to
	    high-intensity (bold = bright foreground, blink = bright background)
	    colours.  The  canonical  names  are  as  follows:	0=black,  1=red,
	    2=green,  3=yellow,  4=blue, 5=magenta, 6=cyan, 7=white, but the ac-
	    tual colour names used are listed in the COLORS  AND  GRAPHICS  sec-
	    tion.

     colorBD: colour
	    Use  the  specified colour to display bold characters when the fore-
	    ground colour is the default.

     colorUL: colour
	    Use the specified colour to display underlined characters  when  the
	    foreground colour is the default.

     colorRV: colour
	    Use the specified colour as the background for reverse video charac-
	    ters.

     cursorColor: colour
	    Use  the specified colour for the cursor.  The default is to use the
	    foreground colour; option -cr.

     cursorColor2: colour
	    Use the specified colour for the colour of	the  cursor  text.   For
	    this  to  take  effect, cursorColor must also be specified.  The de-
	    fault is to use the background colour.

     reverseVideo: boolean
	    True: simulate reverse video by foreground and  background	colours;
	    option  -rv.   False:  regular screen colours [default]; option +rv.
	    See note in COLORS AND GRAPHICS section.

     jumpScroll: boolean
	    True: specify that jump scrolling should be  used.	 When  scrolling
	    quickly,  fewer  screen  updates are performed [default]; option -j.
	    False: specify that smooth scrolling should be used; option +j.

     inheritPixmap: boolean
	    True: make the background inherit the parent windows' pixmap, giving
	    artificial transparency.  False: do not inherit the parent	windows'
	    pixmap.

     scrollColor: colour
	    Use the specified colour for the scrollbar [default #B2B2B2].

     troughColor: colour
	    Use  the  specified  colour for the scrollbar's trough area [default
	    #969696].  Only relevant for normal (non XTerm/NeXT) scrollbar.

     backgroundPixmap: file[;geom]
	    Use the specified XPM file (note the `.xpm' extension  is  optional)
	    for  the  background  and also optionally specify its scaling with a
	    geometry string WxH+X+Y, in which "W" /  "H"  specify  the	horizon-
	    tal/vertical  scale  (percent) and "X" / "Y" locate the image centre
	    (percent).	A scale of 0 displays the image with tiling.  A scale of
	    1 displays the image without any scaling.  A scale of 2 to 9  speci-
	    fies  an  integer number of images in that direction.  No image will
	    be magnified beyond 10 times its original size.  The maximum permit-
	    ted scale is 1000.	[default 0x0+50+50]

     menu: file[;tag]
	    Read in the specified menu file (note the `.menu' extension  is  op-
	    tional) and also optionally specify a starting tag to find.  See the
	    reference documentation for details on the syntax for the menuBar.

     path: path
	    Specify  the  colon-delimited search path for finding files (XPM and
	    menus), in addition to the paths specified by the RXVTPATH and  PATH
	    environment variables.

     font: fontname
	    Select the main text font used [default 7x14]; option -fn.

     fontn: fontname
	    Specify the alternative font n.  The default font values:

     boldFont: fontname
	    Specify  the  name	of  the bold font to use if colorBD has not been
	    specified and it is not  possible  to  map	the  default  foreground
	    colour  to	colour	8-15 [default NONE].  This font must be the same
	    height and width as the normal font; option -fb.

     mfont: fontname
	    Select the main multiple-character text font used [default k14]; op-
	    tion -fk.

     mfontn: fontname
	    Specify the alternative multiple-character font n.	If compiled  for
	    multiple-character	fonts,	the  Roman  and  multiple-character font
	    sizes should match.

     multichar_encoding: mode
	    Set the encoding mode to be used when multicharacter encoding is re-
	    ceived; eucj: EUC Japanese	encoding  [default  for  Kanji].   sjis:
	    Shift JIS encoding.  big5: BIG5 encoding.  gb: GB encoding.  kr: EUC
	    Korean encoding.  noenc: no encoding; option -km.

     greek_keyboard: mode
	    Set  the  Greek  keyboard translation mode to be used; iso: ISO-8859
	    mapping (elot-928) [default].  ibm: IBM-437  mapping  (DOS	codepage
	    737); option -grk.

     greektoggle_key: keysym
	    Set  the  key  to  toggle  keyboard input between no translation and
	    Greek translation  [default Mode_switch].  For more details, see the
	    distributed file README.greek.

     selectstyle: mode
	    Set mouse selection style to old which is  2.20,  oldword  which  is
	    xterm  style  with	2.20  old word selection, or anything else which
	    gives xterm style selection.

     scrollstyle: mode
	    Set scrollbar style to rxvt, next or xterm

     title: string
	    Set window title string, the default title is the command-line spec-
	    ified after the -e option, if any, otherwise the  application  name;
	    option -title.

     iconName: string
	    Set the name used to label the window's icon or displayed in an icon
	    manager window, it also sets the window's title unless it is explic-
	    itly set; option -n.

     mapAlert: boolean
	    True:  de-iconify  (map)  on receipt of a bell character.  False: no
	    de-iconify (map) on receipt of a bell character [default].

     visualBell: boolean
	    True: use visual bell on receipt of a bell	character;  option  -vb.
	    False: no visual bell [default]; option +vb.

     loginShell: boolean
	    True:  start  as a login shell by prepending a `-' to argv[0] of the
	    shell; option -ls.	False: start as a  normal  sub-shell  [default];
	    option +ls.

     utmpInhibit: boolean
	    True:  inhibit  writing record into the system log file utmp; option
	    -ut.  False: write record into the system log file	utmp  [default];
	    option +ut.

     print-pipe: string
	    Specify  a	command  pipe  for  vt100 printer [default lpr(1)].  Use
	    Print to initiate a screen dump to the  printer  and  Ctrl-Print  or
	    Shift-Print to include the scrollback as well.

     scrollBar: boolean
	    True:  enable  the	scrollbar [default]; option -sb.  False: disable
	    the scrollbar; option +sb.

     scrollBar_right: boolean
	    True: place the scrollbar on the right of the  window;  option  -sr.
	    False: place the scrollbar on the left of the window; option +sr.

     scrollBar_floating: boolean
	    True:  display  an	rxvt  scrollbar  without  a  trough; option -st.
	    False: display an rxvt scrollbar with a trough; option +st.

     scrollBar_align: mode
	    Align the top, bottom or centre [default]  of  the	scrollbar  thumb
	    with the pointer on middle button press/drag.

     scrollTtyOutput: boolean
	    True:  scroll  to  bottom  when  tty  receives  output; option(+si).
	    False: do not  scroll  to  bottom  when  tty  receives  output;  op-
	    tion(-si).

     scrollWithBuffer: boolean
	    True: scroll with scrollback buffer when tty recieves new lines (and
	    scrollTtyOutput  is  False); option(+sw).  False: do not scroll with
	    scrollback buffer when tty recieves new lines; option(-sw).

     scrollTtyKeypress: boolean
	    True: scroll to bottom when a non-special key is  pressed.	 Special
	    keys  are  those  which are intercepted by rxvt for special handling
	    and are not passed onto  the  shell;  option(-sk).	 False:  do  not
	    scroll to bottom when a non-special key is pressed; option(+sk).

     smallfont_key: keysym
	    If	enabled,  use  Alt-keysym  to  toggle to a smaller font [default
	    Alt-<]

     bigfont_key: keysym
	    If enabled, use Alt-keysym to  toggle  to  a  bigger  font	[default
	    Alt->]

     saveLines: number
	    Save  number  lines in the scrollback buffer [default 64].	This re-
	    source is limited on most machines to 65535; option -sl.

     internalBorder: number
	    Internal border of number pixels. This resource is limited	to  100;
	    option -b.

     externalBorder: number
	    External  border of number pixels.	This resource is limited to 100;
	    option -w, -bw, -borderwidth.

     termName: termname
	    Specifies the terminal type name to be set in the  TERM  environment
	    variable; option -tn.

     linespace: number
	    Specifies  number of lines (pixel height) to insert between each row
	    of the display [default 0]; option -lsp.

     meta8: boolean
	    True: handle Meta (Alt) + keypress to set the 8th bit.  False:  han-
	    dle Meta (Alt) + keypress as an escape prefix [default].

     mouseWheelScrollPage: boolean
	    True:  the	mouse wheel scrolls a page full.  False: the mouse wheel
	    scrolls five lines [default].

     multibyte_cursor: boolean
	    True: consider multibyte glyphs as single character  for  backspace,
	    delete  and  cursor movement keys; option -mcc.  False: move through
	    all components of all glyphs; option +mcc.

     backspacekey: string
	    The string to send when the backspace key is pressed.  If set to DEC
	    or unset it will send Delete (code 127) or,  if  shifted,  Backspace
	    (code  8)  -  which can be reversed with the appropriate DEC private
	    mode escape sequence.

     deletekey: string
	    The string to send when the delete key (not the keypad  delete  key)
	    is	pressed.  If unset it will send the sequence traditionally asso-
	    ciated with the Execute key.

     cutchars: string
	    The characters used as delimiters for double-click	word  selection.
	    The built-in default:
	    BACKSLASH `"'&()*,;<=>?@[]{|}

     preeditType: style
	    OverTheSpot, OffTheSpot, Root; option -pt.

     inputMethod: name
	    name of inputMethod to use; option -im.

     modifier: modifier
	    Set  the key to be interpreted as the Meta key to: alt, meta, hyper,
	    super, mod1, mod2, mod3, mod4, mod5; option -mod.

     answerbackString: string
	    Specify the reply rxvt sends to the shell when  an	ENQ  (control-E)
	    character  is  passed  through.  It may contain escape values as de-
	    scribed in the entry on keysym following.

     keysym.sym: string
	    Associate string with keysym sym (0xFF00 - 0xFFFF).  It may  contain
	    escape values (\a: bell, \b: backspace, \e, \E: escape, \n: newline,
	    \r:  return, \t: tab, \000: octal number) or control characters (^?:
	    delete, ^@: null, ^A ...) and may enclosed	with  double  quotes  so
	    that  it can start or end with whitespace.	The intervening resource
	    name keysym. cannot be omitted.  This  resource  is  only  available
	    when compiled with KEYSYM_RESOURCE.

THE SCROLLBAR
     Lines  of	text that scroll off the top of the rxvt window (resource: save-
     Lines) and can be scrolled back using the scrollbar or by keystrokes.   The
     normal  rxvt  scrollbar  has  arrows and its behaviour is fairly intuitive.
     The xterm-scrollbar is without arrows and	its  behaviour	mimics	that  of
     xterm

     Scroll  down  with Button1 (xterm-scrollbar) or Shift-Next.  Scroll up with
     Button3 (xterm-scrollbar) or Shift-Prior.	Continuous scroll with Button2.

MOUSE REPORTING
     To temporarily override mouse reporting, for either the  scrollbar  or  the
     normal  text  selection/insertion,  hold either the Shift or the Meta (Alt)
     key while performing the desired mouse action.

     If mouse reporting mode is active, the normal scrollbar  actions  are  dis-
     abled -- on the assumption that we are using a fullscreen application.  In-
     stead, pressing Button1 and Button3 sends ESC[6~ (Next) and ESC[5~ (Prior),
     respectively.   Similarly,  clicking  on the up and down arrows sends ESC[A
     (Up) and ESC[B (Down), respectively.

TEXT SELECTION AND INSERTION
     The behaviour of text selection  and  insertion  mechanism  is  similar  to
     xterm(1).

     Selection:
	    Left  click  at  the beginning of the region, drag to the end of the
	    region and release; Right click to extend the  marked  region;  Left
	    double-click  to  select a word; Left triple-click to select the en-
	    tire line.

     Insertion:
	    Pressing and releasing the Middle mouse button (or Shift-Insert)  in
	    an	rxvt  window causes the current text selection to be inserted as
	    if it had been typed on the keyboard.

CHANGING FONTS
     You can change fonts on-the-fly, which is to say cycle through the  default
     font  and	others of various sizes, by using Shift-KP_Add and Shift-KP_Sub-
     tract.  Or, alternatively (if enabled) with Alt-> and Alt-<, where the  ac-
     tual key can be selected using resources smallfont_key/bigfont_key.

LOGIN STAMP
     rxvt  tries  to write an entry into the utmp(5) file so that it can be seen
     via the who(1) command, and can accept messages.  To  allow  this	feature,
     rxvt must be installed setuid root on some systems.

COLORS AND GRAPHICS
     If  graphics  support was enabled at compile-time, rxvt can be queried with
     ANSI escape sequences and can address individual  pixels  instead	of  text
     characters.  Note the graphics support is still considered beta code.

     In addition to the default foreground and background colours, rxvt can dis-
     play  up  to 16 colours (8 ANSI colours plus high-intensity bold/blink ver-
     sions of the same).  Here is a list  of  the  colours  with  their  rgb.txt
     names.

     It is also possible to specify the colour values of foreground, background,
     cursorColor,  cursorColor2,  colorBD, colorUL as a number 0-15, as a conve-
     nient shorthand to reference the colour name of color0-color15.

     Note that -rv ("reverseVideo: True")  simulates  reverse  video  by  always
     swapping  the  foreground/background  colours.   This  is	in  contrast  to
     xterm(1) where the colours are only swapped if they have not otherwise been
     specified.  For example,

     rxvt -fg Black -bg White -rv
	    would yield White on Black, while on xterm(1) it would  yield  Black
	    on White.

ENVIRONMENT
     rxvt sets the environment variables TERM, COLORTERM and COLORFGBG.  The en-
     vironment	variable  WINDOWID  is set to the X window id number of the rxvt
     window and it also uses and sets the environment variable DISPLAY to  spec-
     ify  which  display  terminal  to use.  rxvt uses the environment variables
     RXVTPATH and PATH to find XPM files.

FILES
     /etc/utmp
	    System file for login records.

     /usr/lib/X11/rgb.txt
	    Color names.

SEE ALSO
     xterm(1), sh(1), resize(1), X(1), pty(4), tty(4), utmp(5)

     See rxvtRef.html rxvtRef.txt for detailed information on recognized  escape
     sequences and menuBar syntax, etc.

BUGS
     Check the BUGS file for an up-to-date list.

     Cursor change support is not yet implemented.

     Click-and-drag doesn't work with X11 mouse report overriding.

     Graphics support is fairly crude.

FTP LOCATION
     rxvt-2.7.10.tar.gz    can	 be   found   at   the	 following   ftp   sites
     ftp://ftp.rxvt.org/pub/rxvt

CURRENT PROJECT COORDINATOR
     Project Coordinator
	    Geoff Wing <gcw@rxvt.org>

     Web page maintainter
	    Oezguer Kesim <oec@rxvt.org>
	    <http://www.rxvt.org/>

     Mailing list
	    The Rxvt Workers <rxvt-workers@rxvt.org> mailing list has also  been
	    established for rxvt development, to subscribe, email to <rxvt-work-
	    ers-subscribe@rxvt.org>.  There is also a mailing list for announce-
	    ments  of  new  releases  of  rxvt. To subscribe, email to <rxvt-an-
	    nounce-subscribe@rxvt.org>.

AUTHORS
     John Bovey
	    University of Kent, 1992, wrote the original Xvt.

     Rob Nation <nation@rocket.sanders.lockheed.com>
	    very heavily modified Xvt and came up with Rxvt

     Angelo Haritsis <ah@doc.ic.ac.uk>
	    wrote the Greek Keyboard Input

     mj olesen <olesen@me.QueensU.CA>
	    Wrote the menu system.
	    Project Coordinator (changes.txt 2.11 to 2.21)

     Oezguer Kesim <kesim@math.fu-berlin.de>
	    Project Coordinator (changes.txt 2.21a to 2.4.5)

     Geoff Wing <gcw@pobox.com>
	    Rewrote screen display and text selection routines.
	    Project Coordinator (changes.txt 2.4.6 - )

X Version 11			  26 MARCH 2003 			 RXVT(1)

home | help